@@ -88,8 +88,8 @@ class TestOldApiHeaderFunctions(FitsTestCase):
         # Write the hdu out and read it back in again--it should be recognized
         # as a PrimaryHDU
         hdu.writeto(self.temp('test.fits'), output_verify='ignore')
-        assert (isinstance(fits.open(self.temp('test.fits'))[0],
-                           fits.PrimaryHDU))
+        assert isinstance(fits.open(self.temp('test.fits'))[0],
+                          fits.PrimaryHDU)
 
         hdu = fits.ImageHDU()
         hdu.header.update('MYKEY', 'FOO', 'BAR')
@@ -158,8 +158,9 @@ class TestOldApiHeaderFunctions(FitsTestCase):
 
     def test_assign_boolean(self):
         """
-        Regression test for #123. Tests assigning Python and Numpy boolean
-        values to keyword values.
+        Regression test for https://trac.assembla.com/pyfits/ticket/123
+
+        Tests assigning Python and Numpy boolean values to keyword values.
         """
 
         fooimg = _pad('FOO     =                    T')
@@ -189,7 +190,7 @@ class TestOldApiHeaderFunctions(FitsTestCase):
         assert h.ascard['BAR'].cardimage == barimg
 
     def test_cardlist_list_methods(self):
-        """Regression test for #190."""
+        """Regression test for https://trac.assembla.com/pyfits/ticket/190"""
 
         header = fits.Header()
         header.update('A', 'B', 'C')
@@ -248,7 +249,7 @@ class TestHeaderFunctions(FitsTestCase):
         c = fits.Card('floatnum', -467374636747637647347374734737437.)
 
         if (str(c) != _pad("FLOATNUM= -4.6737463674763E+32") and
-            str(c) != _pad("FLOATNUM= -4.6737463674763E+032")):
+                str(c) != _pad("FLOATNUM= -4.6737463674763E+032")):
             assert str(c) == _pad("FLOATNUM= -4.6737463674763E+32")
 
     def test_complex_value_card(self):
@@ -425,8 +426,26 @@ class TestHeaderFunctions(FitsTestCase):
             "CONTINUE  '&' / comment long comment long comment long comment long comment     "
             "CONTINUE  '&' / long comment                                                    ")
 
+    def test_long_unicode_string(self):
+        """Regression test for
+        https://github.com/spacetelescope/PyFITS/issues/1
+
+        So long as a unicode string can be converted to ASCII it should have no
+        different behavior in this regard from a byte string.
+        """
+
+        h1 = fits.Header()
+        h1['TEST'] = 'abcdefg' * 30
+
+        h2 = fits.Header()
+        with warnings.catch_warnings(record=True) as w:
+            h2['TEST'] = u'abcdefg' * 30
+            assert len(w) == 0
+
+        assert str(h1) == str(h2)
+
     def test_long_string_repr(self):
-        """Regression test for #193
+        """Regression test for https://trac.assembla.com/pyfits/ticket/193
 
         Ensure that the __repr__() for cards represented with CONTINUE cards is
         split across multiple lines (broken at each *physical* card).
@@ -448,7 +467,7 @@ class TestHeaderFunctions(FitsTestCase):
              str(fits.Card('TEST3', 'Regular value', 'Regular comment'))])
 
     def test_blank_keyword_long_value(self):
-        """Regression test for #194
+        """Regression test for https://trac.assembla.com/pyfits/ticket/194
 
         Test that a blank keyword ('') can be assigned a too-long value that is
         continued across multiple cards with blank keywords, just like COMMENT
@@ -511,7 +530,7 @@ class TestHeaderFunctions(FitsTestCase):
 
     def test_continue_card_with_equals_in_value(self):
         """
-        Regression test for #117.
+        Regression test for https://trac.assembla.com/pyfits/ticket/117
         """
 
         c = fits.Card.fromstring(
@@ -538,14 +557,74 @@ class TestHeaderFunctions(FitsTestCase):
 
         # Test manual creation of hierarch card
         c = fits.Card('hierarch abcdefghi', 10)
-        assert (str(c) ==
-            "HIERARCH abcdefghi = "
-            "10                                                         ")
+        assert str(c) == _pad("HIERARCH abcdefghi = 10")
         c = fits.Card('HIERARCH ESO INS SLIT2 Y1FRML',
-                      'ENC=OFFSET+RESOL*acos((WID-(MAX+MIN))/(MAX-MIN)')
+                        'ENC=OFFSET+RESOL*acos((WID-(MAX+MIN))/(MAX-MIN)')
         assert (str(c) ==
-            "HIERARCH ESO INS SLIT2 Y1FRML= "
-            "'ENC=OFFSET+RESOL*acos((WID-(MAX+MIN))/(MAX-MIN)'")
+                "HIERARCH ESO INS SLIT2 Y1FRML= "
+                "'ENC=OFFSET+RESOL*acos((WID-(MAX+MIN))/(MAX-MIN)'")
+
+    def test_hierarch_with_abbrev_value_indicator(self):
+        """Regression test for
+        https://github.com/spacetelescope/PyFITS/issues/5
+        """
+
+        c = fits.Card.fromstring("HIERARCH key.META_4='calFileVersion'")
+        assert c.keyword == 'key.META_4'
+        assert c.value == 'calFileVersion'
+        assert c.comment == ''
+
+    def test_hierarch_keyword_whitespace(self):
+        """
+        Regression test for
+        https://github.com/spacetelescope/PyFITS/issues/6
+
+        Make sure any leading or trailing whitespace around HIERARCH
+        keywords is stripped from the actual keyword value.
+        """
+
+        c = fits.Card.fromstring(
+                "HIERARCH  key.META_4    = 'calFileVersion'")
+        assert c.keyword == 'key.META_4'
+        assert c.value == 'calFileVersion'
+        assert c.comment == ''
+
+        # Test also with creation via the Card constructor
+        c = fits.Card('HIERARCH  key.META_4', 'calFileVersion')
+        assert c.keyword == 'key.META_4'
+        assert c.value == 'calFileVersion'
+        assert c.comment == ''
+
+    def test_verify_mixed_case_hierarch(self):
+        """Regression test for
+        https://github.com/spacetelescope/PyFITS/issues/7
+
+        Assures that HIERARCH keywords with lower-case characters and other
+        normally invalid keyword characters are not considered invalid.
+        """
+
+        c = fits.Card('HIERARCH WeirdCard.~!@#_^$%&', 'The value',
+                        'a comment')
+        # This should not raise any exceptions
+        c.verify('exception')
+        assert c.keyword == 'WeirdCard.~!@#_^$%&'
+        assert c.value == 'The value'
+        assert c.comment == 'a comment'
+
+        # Test also the specific case from the original bug report
+        header = fits.Header([
+            ('simple', True),
+            ('BITPIX', 8),
+            ('NAXIS', 0),
+            ('EXTEND', True, 'May contain datasets'),
+            ('HIERARCH key.META_0', 'detRow')
+        ])
+        hdu = fits.PrimaryHDU(header=header)
+        hdu.writeto(self.temp('test.fits'))
+        with fits.open(self.temp('test.fits')) as hdul:
+            header2 = hdul[0].header
+            assert (str(header.cards[header.index('key.META_0')]) ==
+                    str(header2.cards[header2.index('key.META_0')]))
 
     def test_missing_keyword(self):
         """Test that accessing a non-existent keyword raises a KeyError."""
@@ -563,12 +642,16 @@ class TestHeaderFunctions(FitsTestCase):
         header['hierarch abcdefghi'] = 10
         assert 'abcdefghi' in header
         assert header['abcdefghi'] == 10
+        # This used to be assert_false, but per ticket
+        # https://trac.assembla.com/pyfits/ticket/155 hierarch keywords
+        # should be treated case-insensitively when performing lookups
         assert 'ABCDEFGHI' in header
 
     def test_hierarch_create_and_update(self):
         """
-        Regression test for #158.  Tests several additional use cases for
-        working with HIERARCH cards.
+        Regression test for https://trac.assembla.com/pyfits/ticket/158
+
+        Tests several additional use cases for working with HIERARCH cards.
         """
 
         msg = 'a HIERARCH card will be created'
@@ -627,10 +710,11 @@ class TestHeaderFunctions(FitsTestCase):
 
     def test_short_hierarch_create_and_update(self):
         """
-        Regression test for #158.  Tests several additional use cases for
-        working with HIERARCH cards, specifically where the keyword is fewer
-        than 8 characters, but contains invalid characters such that it can
-        only be created as a HIERARCH card.
+        Regression test for https://trac.assembla.com/pyfits/ticket/158
+
+        Tests several additional use cases for working with HIERARCH cards,
+        specifically where the keyword is fewer than 8 characters, but contains
+        invalid characters such that it can only be created as a HIERARCH card.
         """
 
         msg = 'a HIERARCH card will be created'
@@ -1170,6 +1254,7 @@ class TestHeaderFunctions(FitsTestCase):
         # a little more clear)
         header.append('')
         assert len(header) == 4
+
         assert header.keys()[-1] == ''
         assert header[''] == ''
         assert header.comments[''] == ''
@@ -1276,19 +1361,19 @@ class TestHeaderFunctions(FitsTestCase):
         header['HISTORY'] = 'DEF'
         header['HISTORY'] = 'GHI'
 
-        assert header['HISTORY'], ['ABC', 'DEF' == 'GHI']
+        assert header['HISTORY'] == ['ABC', 'DEF', 'GHI']
 
         # Single value update
         header['HISTORY'][0] = 'FOO'
-        assert header['HISTORY'], ['FOO', 'DEF' == 'GHI']
+        assert header['HISTORY'] == ['FOO', 'DEF', 'GHI']
 
         # Single value partial slice update
         header['HISTORY'][1:] = 'BAR'
-        assert header['HISTORY'], ['FOO', 'BAR' == 'BAR']
+        assert header['HISTORY'] == ['FOO', 'BAR', 'BAR']
 
         # Multi-value update
         header['HISTORY'][:] = ['BAZ', 'QUX']
-        assert header['HISTORY'], ['BAZ', 'QUX' == 'BAR']
+        assert header['HISTORY'] == ['BAZ', 'QUX', 'BAR']
 
     def test_long_commentary_card(self):
         header = fits.Header()
@@ -1310,7 +1395,7 @@ class TestHeaderFunctions(FitsTestCase):
         assert str(header.cards[2]).rstrip() == 'HISTORY ' + longval[72:]
 
     def test_header_fromtextfile(self):
-        """Regression test for #122.
+        """Regression test for https://trac.assembla.com/pyfits/ticket/122
 
         Manually write a text file containing some header cards ending with
         newlines and ensure that fromtextfile can read them back in.
@@ -1328,7 +1413,7 @@ class TestHeaderFunctions(FitsTestCase):
         assert header == header2
 
     def test_header_fromtextfile_with_end_card(self):
-        """Regression test for #154.
+        """Regression test for https://trac.assembla.com/pyfits/ticket/154
 
         Make sure that when a Header is read from a text file that the END card
         is ignored.
@@ -1351,7 +1436,7 @@ class TestHeaderFunctions(FitsTestCase):
 
     def test_append_end_card(self):
         """
-        Regression test 2 for #154.
+        Regression test 2 for https://trac.assembla.com/pyfits/ticket/154
 
         Manually adding an END card to a header should simply result in a
         ValueError (as was the case in PyFITS 3.0 and earlier).
@@ -1370,7 +1455,7 @@ class TestHeaderFunctions(FitsTestCase):
 
     def test_unnecessary_move(self):
         """
-        Regression test for #125.
+        Regression test for https://trac.assembla.com/pyfits/ticket/125
 
         Ensures that a header is not modified when setting the position of a
         keyword that's already in its correct position.
@@ -1409,7 +1494,7 @@ class TestHeaderFunctions(FitsTestCase):
         assert not header._modified
 
     def test_invalid_float_cards(self):
-        """Regression test for #137."""
+        """Regression test for https://trac.assembla.com/pyfits/ticket/137"""
 
         # Create a header containing two of the problematic cards in the test
         # case where this came up:
@@ -1456,7 +1541,7 @@ class TestHeaderFunctions(FitsTestCase):
 
     def test_invalid_float_cards2(self, capsys):
         """
-        Regression test for #140.
+        Regression test for https://trac.assembla.com/pyfits/ticket/140
         """
 
         # The example for this test requires creating a FITS file containing a
@@ -1484,14 +1569,14 @@ class TestHeaderFunctions(FitsTestCase):
 
     def test_leading_zeros(self):
         """
-        Regression test for #137, part 2.
+        Regression test for https://trac.assembla.com/pyfits/ticket/137, part 2
 
-        Ticket #137 also showed that in float values like 0.001 the leading
-        zero was unnecessarily being stripped off when rewriting the header.
-        Though leading zeros should be removed from integer values to prevent
-        misinterpretation as octal by python (for now PyFITS will still
-        maintain the leading zeros if now changes are made to the value, but
-        will drop them if changes are made).
+        Ticket https://trac.assembla.com/pyfits/ticket/137 also showed that in
+        float values like 0.001 the leading zero was unnecessarily being
+        stripped off when rewriting the header.  Though leading zeros should be
+        removed from integer values to prevent misinterpretation as octal by
+        python (for now PyFITS will still maintain the leading zeros if now
+        changes are made to the value, but will drop them if changes are made).
         """
 
         c = fits.Card.fromstring("APERTURE= +0.000000000000E+000")
@@ -1506,8 +1591,9 @@ class TestHeaderFunctions(FitsTestCase):
 
     def test_assign_boolean(self):
         """
-        Regression test for #123. Tests assigning Python and Numpy boolean
-        values to keyword values.
+        Regression test for https://trac.assembla.com/pyfits/ticket/123
+
+        Tests assigning Python and Numpy boolean values to keyword values.
         """
 
         fooimg = _pad('FOO     =                    T')
@@ -1538,8 +1624,10 @@ class TestHeaderFunctions(FitsTestCase):
 
     def test_header_method_keyword_normalization(self):
         """
-        Regression test for #149.  Basically ensures that all public Header
-        methods are case-insensitive w.r.t. keywords.
+        Regression test for https://trac.assembla.com/pyfits/ticket/149
+
+        Basically ensures that all public Header methods are case-insensitive
+        w.r.t. keywords.
 
         Provides a reasonably comprehensive test of several methods at once.
         """
@@ -1577,7 +1665,7 @@ class TestHeaderFunctions(FitsTestCase):
         assert len(h) == 2
         assert h.setdefault('aBc', 1) == 1
         assert len(h) == 3
-        assert h.keys(), ['GEH', 'DEF' == 'ABC']
+        assert h.keys() == ['GEH', 'DEF', 'ABC']
 
         h.update({'GeH': 1, 'iJk': 4})
         assert len(h) == 4
@@ -1593,8 +1681,10 @@ class TestHeaderFunctions(FitsTestCase):
 
     def test_end_in_comment(self):
         """
-        Regression test for #142.  Tests a case where the comment of a card
-        ends with END, and is followed by several blank cards.
+        Regression test for https://trac.assembla.com/pyfits/ticket/142
+
+        Tests a case where the comment of a card ends with END, and is followed
+        by several blank cards.
         """
 
         data = np.arange(100).reshape((10, 10))
@@ -1631,10 +1721,11 @@ class TestHeaderFunctions(FitsTestCase):
 
     def test_assign_unicode(self):
         """
-        Regression test for #134.  Assigning a unicode literal as a header
-        value should not fail silently.  If the value can be converted to ASCII
-        then it should just work.  Otherwise it should fail with an appropriate
-        value error.
+        Regression test for https://trac.assembla.com/pyfits/ticket/134
+
+        Assigning a unicode literal as a header value should not fail silently.
+        If the value can be converted to ASCII then it should just work.
+        Otherwise it should fail with an appropriate value error.
 
         Also tests unicode for keywords and comments.
         """
@@ -1652,7 +1743,6 @@ class TestHeaderFunctions(FitsTestCase):
         assert repr(h) == _pad("FOO     = 'BAR     '")
         pytest.raises(ValueError, assign, erikku, 'BAR')
 
-
         h['FOO'] = u'BAZ'
         assert h[u'FOO'] == 'BAZ'
         assert h[u'FOO'] == u'BAZ'
@@ -1679,8 +1769,9 @@ class TestHeaderFunctions(FitsTestCase):
 
     def test_header_strip_whitespace(self):
         """
-        Regression test for #146, and for the solution that is optional
-        stripping of whitespace from the end of a header value.
+        Regression test for https://trac.assembla.com/pyfits/ticket/146, and
+        for the solution that is optional stripping of whitespace from the end
+        of a header value.
 
         By default extra whitespace is stripped off, but if
         fits.STRIP_HEADER_WHITESPACE = False it should not be stripped.
@@ -1711,7 +1802,7 @@ class TestHeaderFunctions(FitsTestCase):
 
     def test_keep_duplicate_history_in_orig_header(self):
         """
-        Regression test for #156.
+        Regression test for https://trac.assembla.com/pyfits/ticket/156
 
         When creating a new HDU from an existing Header read from an existing
         FITS file, if the origianl header contains duplicate HISTORY values
@@ -1744,8 +1835,9 @@ class TestHeaderFunctions(FitsTestCase):
 
     def test_invalid_keyword_cards(self):
         """
-        Test for #109.  Allow opening files with headers containing invalid
-        keywords.
+        Test for https://trac.assembla.com/pyfits/ticket/109
+
+        Allow opening files with headers containing invalid keywords.
         """
 
         # Create a header containing a few different types of BAD headers.
@@ -1767,6 +1859,8 @@ class TestHeaderFunctions(FitsTestCase):
             with fits.open(self.temp('test.fits')) as hdul:
                 # Merely opening the file should blast some warnings about the
                 # invalid keywords
+                assert len(w) == 3
+
                 header = hdul[0].header
                 assert 'CLFIND2D' in header
                 assert 'Just som' in header
@@ -1783,14 +1877,30 @@ class TestHeaderFunctions(FitsTestCase):
 
     def test_fix_hierarch_with_invalid_value(self, capsys):
         """
-        Regression test for #172.  Ensures that when fixing a hierarch card it
-        remains a hierarch card.
+        Regression test for https://trac.assembla.com/pyfits/ticket/172
+
+        Ensures that when fixing a hierarch card it remains a hierarch card.
         """
 
         c = fits.Card.fromstring('HIERARCH ESO DET CHIP PXSPACE = 5e6')
         c.verify('fix')
         assert str(c) == _pad('HIERARCH ESO DET CHIP PXSPACE = 5E6')
 
+    def test_assign_inf_nan(self):
+        """
+        Regression test for https://github.com/spacetelescope/PyFITS/issues/11
+
+        For the time being it should not be possible to assign the floating
+        point values inf or nan to a header value, since this is not defined by
+        the FITS standard.
+        """
+
+        h = fits.Header()
+        pytest.raises(ValueError, h.set, 'TEST', float('nan'))
+        pytest.raises(ValueError, h.set, 'TEST', np.nan)
+        pytest.raises(ValueError, h.set, 'TEST', float('inf'))
+        pytest.raises(ValueError, h.set, 'TEST', np.inf)
+
 
 class TestRecordValuedKeywordCards(FitsTestCase):
     """
@@ -1833,7 +1943,7 @@ class TestRecordValuedKeywordCards(FitsTestCase):
         c = fits.Card.fromstring("DP1     = 'NAXIS: a'")
         assert c.keyword == 'DP1'
         assert c.value == 'NAXIS: a'
-        assert c.field_specifier == None
+        assert c.field_specifier is None
 
         c = fits.Card('DP1', 'NAXIS: 2')
         assert c.keyword == 'DP1.NAXIS'
@@ -1848,7 +1958,7 @@ class TestRecordValuedKeywordCards(FitsTestCase):
         c = fits.Card('DP1', 'NAXIS: a')
         assert c.keyword == 'DP1'
         assert c.value == 'NAXIS: a'
-        assert c.field_specifier == None
+        assert c.field_specifier is None
 
         c = fits.Card('DP1.NAXIS', 2)
         assert c.keyword == 'DP1.NAXIS'
@@ -1864,7 +1974,7 @@ class TestRecordValuedKeywordCards(FitsTestCase):
             c = fits.Card('DP1.NAXIS', 'a')
         assert c.keyword == 'DP1.NAXIS'
         assert c.value == 'a'
-        assert c.field_specifier == None
+        assert c.field_specifier is None
 
     def test_parse_field_specifier(self):
         """
@@ -1925,8 +2035,8 @@ class TestRecordValuedKeywordCards(FitsTestCase):
         string of the first card with that keyword.
 
         This test was changed to reflect the requirement in ticket
-        #184--previously it required _test_header['DP1'] to return the parsed
-        float value.
+        https://trac.assembla.com/pyfits/ticket/184--previously it required
+        _test_header['DP1'] to return the parsed float value.
         """
 
         assert self._test_header['DP1'] == 'NAXIS: 2'
@@ -2080,7 +2190,7 @@ class TestRecordValuedKeywordCards(FitsTestCase):
 
     def test_overly_permissive_parsing(self):
         """
-        Regression test for #183.
+        Regression test for https://trac.assembla.com/pyfits/ticket/183
 
         Ensures that cards with standard commentary keywords are never treated
         as RVKCs.  Also ensures that cards not stricly matching the RVKC
@@ -2101,8 +2211,7 @@ class TestRecordValuedKeywordCards(FitsTestCase):
         h = fits.Header()
         h['HISTORY'] = 'Date: 2012-09-19T13:58:53.756061'
         assert 'HISTORY.Date' not in h
-        assert (str(h.cards[0]) ==
-                _pad('HISTORY Date: 2012-09-19T13:58:53.756061'))
+        assert str(h.cards[0]) == _pad('HISTORY Date: 2012-09-19T13:58:53.756061')
 
         c = fits.Card.fromstring(
             "        'Date: 2012-09-19T13:58:53.756061'")
@@ -2118,7 +2227,7 @@ class TestRecordValuedKeywordCards(FitsTestCase):
 
     def test_overly_aggressive_rvkc_lookup(self):
         """
-        Regression test for #184.
+        Regression test for https://trac.assembla.com/pyfits/ticket/184
 
         Ensures that looking up a RVKC by keyword only (without the
         field-specifier) in a header returns the full string value of that card
