@@ -378,6 +378,8 @@ def register_commands(package, version, release):
 
     if HAVE_SPHINX:
         _registered_commands['build_sphinx'] = AstropyBuildSphinx
+    else: 
+         _registered_commands['build_sphinx'] = FakeBuildSphinx
 
     # Need to override the __name__ here so that the commandline options are
     # presented as being related to the "build" command, for example; normally
@@ -534,6 +536,22 @@ def generate_build_ext_command(release):
 
 class AstropyBuildPy(SetuptoolsBuildPy):
 
+    def finalize_options(self):
+        # Update build_lib settings from the build command to always put
+        # build files in platform-specific subdirectories of build/, even
+        # for projects with only pure-Python source (this is desirable
+        # specifically for support of multiple Python version).
+        build_cmd = self.get_finalized_command('build')
+        plat_specifier = '.{0}-{1}'.format(build_cmd.plat_name,
+                                           sys.version[0:3])
+        # Do this unconditionally
+        build_purelib = os.path.join(build_cmd.build_base,
+                                     'lib' + plat_specifier)
+        build_cmd.build_purelib = build_purelib
+        build_cmd.build_lib = build_purelib
+        self.build_lib = build_purelib
+        SetuptoolsBuildPy.finalize_options(self)
+
     def run(self):
         # first run the normal build_py
         SetuptoolsBuildPy.run(self)
@@ -585,7 +603,9 @@ def generate_default_config(build_lib, package):
     else:
         msg = ('Generation of default configuration item failed! Stdout '
                'and stderr are shown below.\n'
-               'Stdout:\n{stdout}\nStderr:\n{stderr}').decode('UTF-8')
+               'Stdout:\n{stdout}\nStderr:\n{stderr}')
+        if isinstance(msg, bytes):
+            msg = msg.decode('UTF-8')
         log.error(msg.format(stdout=stdout.decode('UTF-8'),
                              stderr=stderr.decode('UTF-8')))
 
@@ -754,12 +774,16 @@ if HAVE_SPHINX:
             SphinxBuildDoc.finalize_options(self)
 
         def run(self):
+            import webbrowser
+
             from os.path import split, join, abspath
             from distutils.cmd import DistutilsOptionError
             from subprocess import Popen, PIPE
             from inspect import getsourcelines
-            from urllib import pathname2url
-            import webbrowser
+            if PY3:
+                from urllib.request import pathname2url
+            else:
+                from urllib import pathname2url
 
             # If possible, create the _static dir
             if self.build_dir is not None:
@@ -790,8 +814,8 @@ if HAVE_SPHINX:
             subproccode = textwrap.dedent("""
             from sphinx.setup_command import *
 
-            os.chdir('{srcdir}')
-            sys.path.insert(0,'{build_cmd_path}')
+            os.chdir({srcdir!r})
+            sys.path.insert(0, {build_cmd_path!r})
 
             """).format(build_cmd_path=build_cmd_path, srcdir=self.source_dir)
             #runlines[1:] removes 'def run(self)' on the first line
@@ -823,7 +847,7 @@ if HAVE_SPHINX:
                       '[CODE END])'.format(sys.executable, subproccode))
 
             proc = Popen([sys.executable], stdin=PIPE)
-            proc.communicate(subproccode)
+            proc.communicate(subproccode.encode('utf-8'))
             if proc.returncode == 0:
                 if self.open_docs_in_browser:
                     if self.builder == 'html':
@@ -1567,3 +1591,42 @@ class bdist_dmg(Command):
 
         # Remove temporary disk image
         os.remove(dmg_path_tmp)
+
+
+class FakeBuildSphinx(Command):
+    """
+    A dummy build_sphinx command that is called if Sphinx is not
+    installed and displays a relevant error message
+    """
+
+    #user options inherited from sphinx.setup_command.BuildDoc
+    user_options = [
+         ('fresh-env', 'E', '' ),
+         ('all-files', 'a', ''),
+         ('source-dir=', 's', ''),
+         ('build-dir=', None, ''),
+         ('config-dir=', 'c', ''),
+         ('builder=', 'b', ''),
+         ('project=', None, ''),
+         ('version=', None, ''),
+         ('release=', None, ''),
+         ('today=', None, ''),
+         ('link-index', 'i', ''),
+     ] 
+
+    #user options appended in astropy.setup_helpers.AstropyBuildSphinx
+    user_options.append(('warnings-returncode', 'w',''))
+    user_options.append(('clean-docs', 'l', ''))
+    user_options.append(('no-intersphinx', 'n', ''))
+    user_options.append(('open-docs-in-browser', 'o',''))
+ 
+                               
+
+    def initialize_options(self):
+        try:
+            raise RuntimeError("Sphinx must be installed for build_sphinx")
+        except:
+            log.error('error : Sphinx must be installed for build_sphinx')
+            sys.exit(1)
+
+    
