@@ -421,6 +421,22 @@ class Time(object):
 
         return tm
 
+    def __copy__(self):
+        """
+        Overrides the default behavior of the `copy.copy` function in
+        the python stdlib to behave like `Time.copy`. Does *not* make a
+        copy of the JD arrays - only copies by reference.
+        """
+        return self.replicate()
+
+    def __deepcopy__(self, memo):
+        """
+        Overrides the default behavior of the `copy.deepcopy` function
+        in the python stdlib to behave like `Time.copy`. Does make a
+        copy of the JD arrays.
+        """
+        return self.copy()
+
     def _getAttributeNames(self):
         """
         Add dynamic attribute names for IPython completer.
