@@ -12,12 +12,12 @@ from __future__ import (absolute_import, unicode_literals, division,
 # Standard library
 import copy
 import numbers
+import warnings
 
 import numpy as np
 
 # AstroPy
 from .core import Unit, UnitBase, CompositeUnit
-from .. import log
 from ..config import ConfigurationItem
 
 WARN_IMPLICIT_NUMERIC_CONVERSION = ConfigurationItem(
@@ -214,6 +214,8 @@ class Quantity(object):
         if isinstance(other, Quantity):
             return Quantity(self.value * other.value,
                             unit=self.unit * other.unit)
+        elif isinstance(other, basestring):
+            return Quantity(self.value, unit=Unit(other) * self.unit)
         elif isinstance(other, UnitBase):
             return Quantity(self.value, unit=other * self.unit)
         else:
@@ -237,6 +239,8 @@ class Quantity(object):
         if isinstance(other, Quantity):
             return Quantity(self.value / other.value,
                             unit=self.unit / other.unit)
+        elif isinstance(other, basestring):
+            return Quantity(self.value, unit=self.unit / Unit(other))
         elif isinstance(other, UnitBase):
             return Quantity(self.value, unit=self.unit / other)
         else:
@@ -253,6 +257,8 @@ class Quantity(object):
         if isinstance(other, Quantity):
             return Quantity(other.value / self.value,
                             unit=other.unit / self.unit)
+        elif isinstance(other, basestring):
+            return Quantity(self.value, unit=Unit(other) / self.unit)
         elif isinstance(other, UnitBase):
             return Quantity(1. / self.value, unit=other / self.unit)
         else:
@@ -347,6 +353,19 @@ class Quantity(object):
     def __hash__(self):
         return hash(self.value) ^ hash(self.unit)
 
+    def __iter__(self):
+        if self.isscalar:
+            raise TypeError(
+                "'{cls}' object with a scalar value is not iterable"
+                .format(cls=self.__class__.__name__))
+
+        # Otherwise return a generator
+        def quantity_iter():
+            for val in self.value:
+                yield Quantity(val, unit=self.unit)
+
+        return quantity_iter()
+
     def __getitem__(self, key):
         if self.isscalar:
             raise TypeError(
@@ -377,8 +396,8 @@ class Quantity(object):
         # We show a warning unless the unit is equivalent to unity (i.e. not
         # just dimensionless, but also with a scale of 1)
         if not _is_unity(self.unit) and WARN_IMPLICIT_NUMERIC_CONVERSION():
-            log.warn("Converting Quantity object in units '{0}' to a Python "
-                     "scalar".format(self.unit))
+            warnings.warn("Converting Quantity object in units '{0}' to a "
+                          "Python scalar".format(self.unit))
         return float(self.value)
 
     def __int__(self):
@@ -388,8 +407,8 @@ class Quantity(object):
         # We show a warning unless the unit is equivalent to unity (i.e. not
         # just dimensionless, but also with a scale of 1)
         if not _is_unity(self.unit) and WARN_IMPLICIT_NUMERIC_CONVERSION():
-            log.warn("Converting Quantity object in units '{0}' to a Python "
-                     "scalar".format(self.unit))
+            warnings.warn("Converting Quantity object in units '{0}' to a "
+                          "Python scalar".format(self.unit))
         return int(self.value)
 
     def __long__(self):
@@ -399,8 +418,8 @@ class Quantity(object):
         # We show a warning unless the unit is equivalent to unity (i.e. not
         # just dimensionless, but also with a scale of 1)
         if not _is_unity(self.unit) and WARN_IMPLICIT_NUMERIC_CONVERSION():
-            log.warn("Converting Quantity object in units '{0}' to a Python "
-                     "scalar".format(self.unit))
+            warnings.warn("Converting Quantity object in units '{0}' to a "
+                          "Python scalar".format(self.unit))
         return long(self.value)
 
     # Array types
@@ -408,8 +427,8 @@ class Quantity(object):
         # We show a warning unless the unit is equivalent to unity (i.e. not
         # just dimensionless, but also with a scale of 1)
         if not _is_unity(self.unit) and WARN_IMPLICIT_NUMERIC_CONVERSION():
-            log.warn("Converting Quantity object in units '{0}' to a Numpy "
-                     "array".format(self.unit))
+            warnings.warn("Converting Quantity object in units '{0}' to a "
+                          "Numpy array".format(self.unit))
         return np.array(self.value)
 
     # Display
